#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['copyifc']

package_data = \
{'': ['*']}

setup(name='copyifc',
      version='0.1.1',
      description='Author:     LanHao',
      author='LHao',
      author_email='bigpangl@163.com',
      url='https://github.com/bigpangl/copyifc',
      packages=packages,
      package_data=package_data,
     )
